jaraco.translation
==================

Natural language translation support using Google APIs.


pmxbot plugin
-------------

jaraco.translate supplies a plugin for `pmxbot
<https://bitbucket.org/yougov/pmxbot>`_.

To enable, simply install this package alongside pmxbot and
add your Google API key to the pmxbot config::

    google_translate_API_key: AB2x...

and then `!translate` away.
